| Title: | Isotonic Designs for Phase 1 Trials with Late-Onset Toxicities |
|---|---|
| Description: | Functions to design phase 1 trials using an isotonic regression based design incorporating time-to-event information. Simulation and design functions are available, which incorporate information about followup and DLTs, and apply isotonic regression to devise estimates of DLT probability. |
| Authors: | Lee McDaniel [aut, cre] |
| Maintainer: | Lee McDaniel <[email protected]> |
| License: | GPL-3 |
| Version: | 0.1.0 |
| Built: | 2026-06-10 09:52:37 UTC |
| Source: | https://github.com/cran/titeIR |
Calculate the next dose assignment for a TITE-IR design.
isotitedose(followup, DLT, assignment, obswin, doses, target = 1/3, safety = 0.05)isotitedose(followup, DLT, assignment, obswin, doses, target = 1/3, safety = 0.05)
followup |
A vector of followup times |
DLT |
A vector of DLT results. |
assignment |
a vector of dose assignments. Doses should be labeled in consecutive integers from 1 to number of dose levels. |
obswin |
The observation window with respect to which the MTD is defined. |
doses |
An integer providing the number of doses. |
target |
Target DLT rate |
safety |
The safety factor to prevent overly aggressive escalation |
an integer specifying the recommended dose level
isotitesim for simulations
isotitedose(followup = c(6, 5, 4, 3, 2, 1), DLT = c(0, 0, 0, 0, 0, 0), assignment = c(1, 1, 1, 2, 2, 2), obswin = 6, doses = 6)isotitedose(followup = c(6, 5, 4, 3, 2, 1), DLT = c(0, 0, 0, 0, 0, 0), assignment = c(1, 1, 1, 2, 2, 2), obswin = 6, doses = 6)
Simulates trials based on the TITE-IR design.
isotitesim(PI, target, n, nsim, obswin = 1, rate = 1, safety = 0.05, accrual = "poisson", restrict = TRUE)isotitesim(PI, target, n, nsim, obswin = 1, rate = 1, safety = 0.05, accrual = "poisson", restrict = TRUE)
PI |
A vector of true toxicity probabilities at each dose |
target |
Target DLT rate |
n |
Sample size of the trial |
nsim |
Number of trial replicates |
obswin |
The observation window with respect to which the MTD is defined |
rate |
Patient arrival rate: expected number of arrivals per observation window |
safety |
The safety factor to prevent overly aggressive escalation |
accrual |
Specify the accrual distribution. Can be either |
restrict |
If |
Object of type isotite which provides results from TITE-IR simulations
isotitedose for dose recommendation
isotitesim(PI = c(0.05, 0.10, 0.20, 0.30, 0.50, 0.70), target = 1/3, n = 24, nsim = 10, obswin = 6, rate = 12)isotitesim(PI = c(0.05, 0.10, 0.20, 0.30, 0.50, 0.70), target = 1/3, n = 24, nsim = 10, obswin = 6, rate = 12)